@@ -5,6 +5,7 @@ Functions to find the pipeline inputs and communicate with the SM server
 import logging
 import sys
 from dataclasses import dataclass
+from os.path import join
 from typing import List, Dict, Optional, Set, Collection
 
 import pandas as pd
@@ -238,6 +239,7 @@ def replace_paths_to_test(s: Dict) -> Optional[Dict]:
 default_entry = {
     's': None,
     'external_id': None,
+    'stack': None,
     'project': None,
     'source': '-',
     'continental_pop': '-',
@@ -260,10 +262,14 @@ default_entry = {
     'r_chimera': None,
     'r_duplication': None,
     'median_insert_size': None,
+    'median_coverage': None,
+    'r_30x': None,
+    'r_aligned_in_pairs': None,
     'fam_id': '-',
     'mat_id': '-',
     'pat_id': '-',
     'sex': '-',
+    'sex_karyotype': '-',
     'age': None,
 }
 
@@ -273,6 +279,7 @@ def find_inputs_from_db(
     skip_samples: Optional[Collection[str]] = None,
     check_existence: bool = True,
     source_tag: Optional[str] = None,
+    assume_gvcfs_are_ready: bool = False,
 ) -> pd.DataFrame:
     """
     Determine input samples and pull input files and metadata from the CPG
@@ -316,106 +323,125 @@ def find_inputs_from_db(
         if source_tag:
             meta['source'] = source_tag
 
-        reblocked_gvcf_analysis_per_sid = find_analyses_by_sid(
+        qc_analysis_per_sid = find_analyses_by_sid(
             sample_ids=[s['id'] for s in samples],
-            analysis_type=AnalysisType('gvcf'),
+            analysis_type='qc',
             project=proj,
-            meta=dict(staging=False, **meta),
+            meta=dict(**meta),
         )
 
-        staging_gvcf_analysis_per_sid = dict()
-        if source_tag is not None:
-            staging_gvcf_analysis_per_sid = find_analyses_by_sid(
+        reblocked_gvcf_by_sid: Dict[str, str] = {}
+        staging_gvcf_by_sid: Dict[str, str] = {}
+        if assume_gvcfs_are_ready:
+            if proj.endswith('-test'):
+                stack = proj.replace('-test', '')
+                namespace = 'test'
+            else:
+                stack = proj
+                namespace = 'main'
+            proj_bucket = f'gs://cpg-{stack}-{namespace}/gvcf'
+            if source_tag:
+                proj_bucket = join(proj_bucket, source_tag)
+            reblocked_gvcf_by_sid = {
+                s['id']: join(proj_bucket, f'{s["id"]}.g.vcf.gz')
+                for s in samples
+            }
+        else:
+            reblocked_gvcf_analysis_per_sid = find_analyses_by_sid(
                 sample_ids=[s['id'] for s in samples],
+                analysis_type='gvcf',
                 project=proj,
-                analysis_type=AnalysisType('gvcf'),
-                meta=dict(staging=True, **meta),
+                meta=dict(staging=False, **meta),
             )
+            staging_gvcf_analysis_per_sid = dict()
+            if source_tag is not None:
+                staging_gvcf_analysis_per_sid = find_analyses_by_sid(
+                    sample_ids=[s['id'] for s in samples],
+                    project=proj,
+                    analysis_type='gvcf',
+                    meta=dict(staging=True, **meta),
+                )
 
-        reblocked_gvcf_by_sid = dict()
-        staging_gvcf_by_sid = dict()
-        sids_without_gvcf = []
-        for s in samples:
-            reblocked_gvcf_analysis = reblocked_gvcf_analysis_per_sid.get(s['id'])
-            staging_gvcf_analysis = staging_gvcf_analysis_per_sid.get(s['id'])
-            if not reblocked_gvcf_analysis and not staging_gvcf_analysis:
-                sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
+            sids_without_gvcf = []
+            for s in samples:
+                reblocked_gvcf_analysis = reblocked_gvcf_analysis_per_sid.get(s['id'])
+                staging_gvcf_analysis = staging_gvcf_analysis_per_sid.get(s['id'])
+                if not reblocked_gvcf_analysis and not staging_gvcf_analysis:
+                    sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
+                    continue
+    
+                if reblocked_gvcf_analysis:
+                    if not reblocked_gvcf_analysis.output:
+                        logger.error(
+                            f'"output" is not defined for the latest reblocked gvcf '
+                            f' analysis, skipping sample {s["id"]}'
+                        )
+                        sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
+                        continue
+                    reblocked_gvcf_by_sid[s['id']] = reblocked_gvcf_analysis.output
+    
+                if staging_gvcf_analysis:
+                    if not staging_gvcf_analysis.output:
+                        logger.error(
+                            f'"output" is not defined for the latest staging gvcf analysis, '
+                            f'skipping sample {s["id"]}'
+                        )
+                        sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
+                        continue
+                    staging_gvcf_by_sid[s['id']] = staging_gvcf_analysis.output
+    
+            if sids_without_gvcf:
+                logger.warning(
+                    f'No gvcf found for {len(sids_without_gvcf)}/{len(samples)} samples: '
+                    f'{", ".join(sids_without_gvcf)}'
+                )
+            samples = [
+                s
+                for s in samples
+                if s['id'] in reblocked_gvcf_by_sid or s['id'] in staging_gvcf_by_sid
+            ]
+            if not samples:
+                logger.info(f'No samples to process, skipping project {proj}')
                 continue
 
-            if reblocked_gvcf_analysis:
-                if not reblocked_gvcf_analysis.output:
-                    logger.error(
-                        f'"output" is not defined for the latest reblocked gvcf analysis, '
-                        f'skipping sample {s["id"]}'
-                    )
-                    sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
-                    continue
-                reblocked_gvcf_by_sid[s['id']] = reblocked_gvcf_analysis.output
-
-            if staging_gvcf_analysis:
-                if not staging_gvcf_analysis.output:
-                    logger.error(
-                        f'"output" is not defined for the latest staging gvcf analysis, '
-                        f'skipping sample {s["id"]}'
-                    )
-                    sids_without_gvcf.append(s['id'] + '/' + s['external_id'])
-                    continue
-                staging_gvcf_by_sid[s['id']] = staging_gvcf_analysis.output
-
-        if sids_without_gvcf:
-            logger.warning(
-                f'No gvcf found for {len(sids_without_gvcf)}/{len(samples)} samples: '
-                f'{", ".join(sids_without_gvcf)}'
-            )
-        samples = [
-            s
-            for s in samples
-            if s['id'] in reblocked_gvcf_by_sid or s['id'] in staging_gvcf_by_sid
-        ]
-        if not samples:
-            logger.info(f'No samples to process, skipping project {proj}')
-            continue
-
         logger.info('Checking sequencing info for samples')
+        seq_meta_by_sid = dict()
         try:
             seq_infos: List[Dict] = seqapi.get_sequences_by_sample_ids(
                 request_body=[s['id'] for s in samples]
             )
         except exceptions.ApiException:
-            logger.critical(f'Not for all samples sequencing data was found')
-            raise
-        seq_meta_by_sid: Dict = dict()
-        sids_without_meta = []
-        for si in seq_infos:
-            if 'meta' not in si:
-                sids_without_meta.append(si['sample_id'])
-            else:
-                seq_meta_by_sid[si['sample_id']] = si['meta']
-        if sids_without_meta:
-            logger.warning(
-                f'Found {len(sids_without_meta)} samples without "meta" in '
-                f'sequencing info: {", ".join(sids_without_meta)}'
-            )
-        logger.info(f'Found {len(seq_meta_by_sid)} sequences')
-
-        samples = [s for s in samples if s['id'] in seq_meta_by_sid]
-        if not samples:
-            logger.info(f'No samples to process, skipping project {proj}')
-            continue
+            logger.warning(f'Sequencing data was not found for some samples')
+        else:
+            sids_without_meta = []
+            for si in seq_infos:
+                if 'meta' not in si:
+                    sids_without_meta.append(si['sample_id'])
+                else:
+                    seq_meta_by_sid[si['sample_id']] = si['meta']
+            if sids_without_meta:
+                logger.warning(
+                    f'Found {len(sids_without_meta)} samples without "meta" in '
+                    f'sequencing info: {", ".join(sids_without_meta)}'
+                )
+            logger.info(f'Found {len(seq_meta_by_sid)} sequences')
 
         logger.info(
-            'Checking GVCFs for samples and collecting pipeline input data frame'
+            'Checking GVCFs for samples and collecting pipeline input DataFrame'
         )
         for s in samples:
             sample_id = s['id']
             external_id = s['external_id']
-            resequencing_label = '-'
-            if '-' in external_id:
-                external_id, resequencing_label = external_id.split('-', maxsplit=1)
-            seq_meta = seq_meta_by_sid[sample_id]
+            seq_meta = seq_meta_by_sid.get(sample_id, {})
             reblocked_gvcf_path = reblocked_gvcf_by_sid.get(s['id'])
             staging_gvcf_path = staging_gvcf_by_sid.get(s['id'])
 
+            qc_analysis = qc_analysis_per_sid.get(sample_id)
+            if qc_analysis:
+                qc_metrics = qc_analysis.meta.get('metrics', {})
+            else:
+                qc_metrics = {} 
+
             def _check_gvcf(gvcf_path):
                 if not gvcf_path.endswith('.g.vcf.gz'):
                     logger.warning(
@@ -446,10 +472,11 @@ def find_inputs_from_db(
                     's': sample_id,
                     'external_id': external_id,
                     'fam_id': external_id,
-                    'project': proj.replace('-test', ''),
+                    'stack': proj.replace('-test', ''),
+                    'project': s['meta'].get('project', proj.replace('-test', '')),
                     'source': source_tag or '-',
-                    'gvcf': reblocked_gvcf_path,
-                    'topostproc_gvcf': staging_gvcf_path,
+                    'gvcf': reblocked_gvcf_path or '-',
+                    'topostproc_gvcf': staging_gvcf_path or '-',
                     'batch': seq_meta.get('batch', '-'),
                     'flowcell_lane': seq_meta.get(
                         'sample.flowcell_lane', seq_meta.get('flowcell_lane', '-')
@@ -463,22 +490,17 @@ def find_inputs_from_db(
                     'centre': seq_meta.get(
                         'sample.centre', seq_meta.get('centre', '-')
                     ),
-                    'primary_study': seq_meta.get('Primary study', 'TOB'),
-                    'resequencing_label': resequencing_label,
-                    'r_contamination': seq_meta.get(
-                        'raw_data.FREEMIX', seq_meta.get('freemix')
-                    ),
-                    'r_chimera': seq_meta.get(
-                        'raw_data.PCT_CHIMERAS', seq_meta.get('pct_chimeras')
-                    ),
-                    'r_duplication': seq_meta.get(
-                        'raw_data.PERCENT_DUPLICATION',
-                        seq_meta.get('percent_duplication'),
-                    ),
-                    'median_insert_size': seq_meta.get(
-                        'raw_data.MEDIAN_INSERT_SIZE',
-                        seq_meta.get('median_insert_size'),
-                    ),
+                    'primary_study': seq_meta.get('Primary study', '-'),
+                    # QC metrics:
+                    'r_contamination': qc_metrics.get('freemix'),
+                    'r_chimera': qc_metrics.get('pct_chimeras'),
+                    'r_duplication': qc_metrics.get('percent_duplication'),
+                    'median_insert_size': qc_metrics.get('median_insert_size'),
+                    'median_coverage': qc_metrics.get('median_coverage'),
+                    'r_30x': qc_metrics.get('pct_30x'),
+                    'r_aligned_in_pairs': qc_metrics.get('pct_reads_aligned_in_pairs'),
+                    'continental_pop': s['meta'].get('continental_pop', '-'),
+                    'subpop': s['meta'].get('subpop', '-'),
                 }
             )
             inputs.append(entry)
@@ -521,6 +543,7 @@ def add_validation_samples(df: pd.DataFrame) -> pd.DataFrame:
                     'external_id': sn,
                     'fam_id': 'CEPH',
                     'sex': '1' if sn == 'NA12891' else '2',
+                    'sex_karyotype': 'XY' if sn == 'NA12891' else 'XX',
                     'pat_id': 'NA12891' if sn == 'NA12878' else '-',
                     'mat_id': 'NA12892' if sn == 'NA12878' else '-',
                     'project': 'giab',
