@@ -15,6 +15,7 @@ import pandas as pd
 import click
 import hail as hl
 from hail.experimental.vcf_combiner import vcf_combiner
+from hail.experimental.vcf_combiner.vcf_combiner import CombinerConfig
 
 from joint_calling.utils import get_validation_callback
 from joint_calling import utils
@@ -43,6 +44,23 @@ TARGET_RECORDS = 25_000
     callback=get_validation_callback(ext='mt'),
     help='path to write the combined MatrixTable',
 )
+@click.option(
+    '--branch-factor',
+    'branch_factor',
+    required=False,
+    type=click.INT,
+    default=CombinerConfig.default_branch_factor,
+    help='Combiner branch factor (gvcfs will be split into ~branch_factor batches)',
+)
+@click.option(
+    '--batch-size',
+    'batch_size',
+    required=False,
+    type=click.INT,
+    default=CombinerConfig.default_phase1_batch_size,
+    help='Combiner batch size for phase1 (size of each batch of gvcfs to process '
+         'in 1 job)',
+)
 @click.option(
     '--existing-mt',
     'existing_mt_path',
@@ -86,6 +104,8 @@ TARGET_RECORDS = 25_000
 def main(
     meta_csv_path: str,
     out_mt_path: str,
+    branch_factor: int,
+    batch_size: int,
     existing_mt_path: str,
     work_bucket: str,
     local_tmp_dir: str,
@@ -110,6 +130,8 @@ def main(
         sample_names=list(new_samples_df.s),
         out_mt_path=new_mt_path,
         work_bucket=work_bucket,
+        branch_factor=branch_factor,
+        batch_size=batch_size,
         overwrite=True,
     )
     new_mt = hl.read_matrix_table(new_mt_path)
@@ -168,6 +190,8 @@ def combine_gvcfs(
     sample_names: List[str],
     out_mt_path: str,
     work_bucket: str,
+    branch_factor: int,
+    batch_size: int,
     overwrite: bool = True,
 ):
     """
@@ -182,6 +206,8 @@ def combine_gvcfs(
         tmp_path=os.path.join(work_bucket, 'tmp'),
         overwrite=overwrite,
         key_by_locus_and_alleles=True,
+        branch_factor=branch_factor,
+        batch_size=batch_size,
     )
 
 
